@@ -3,7 +3,8 @@ from __future__ import annotations
 from dataclasses import dataclass
 from typing import Optional
 
-from .model import FetcherMetadata, PipelinesConfig
+from dbnomics_fetcher_ops.model.fetcher_metadata.gitlab import GitLabFetcherMetadata
+from dbnomics_fetcher_ops.model.pipelines_config import PipelinesConfig
 
 __all__ = ["get_app_args", "AppArgs"]
 
@@ -20,7 +21,7 @@ def get_app_args() -> AppArgs:
 class AppArgs:
     """Script arguments common to all commands."""
 
-    fetcher_metadata: FetcherMetadata
+    fetcher_metadata: GitLabFetcherMetadata
     fetchers_yml: str
     pipelines_config: PipelinesConfig
     pipelines_yml: str
