@@ -9,6 +9,7 @@ from typing import Optional
 import daiquiri
 import typer
 from dotenv import load_dotenv
+from humanfriendly import format_path
 from xdg import xdg_config_home
 
 from . import app_args, commands, loaders
@@ -22,7 +23,7 @@ daiquiri.set_default_log_levels([(__package__, logging.INFO)])
 config_env_file = xdg_config_home() / "dbnomics" / "dbnomics-fetchers.env"
 if config_env_file.is_file():
     load_dotenv(config_env_file)
-    logger.info("Environment variables loaded from %r", str(config_env_file))
+    logger.info("Environment variables loaded from %r", format_path(str(config_env_file)))
 load_dotenv()
 
 app = typer.Typer()
