@@ -6,19 +6,21 @@ from time import sleep
 from typing import Iterable, Optional, cast
 
 import daiquiri
-import typer
-
 import gitlab
-from dbnomics_fetcher_ops.cli_utils import check_provider_slug_is_lowercase, get_fetcher_def_not_found_error_message
+import typer
 from gitlab.const import Visibility
 from gitlab.v4.objects import DeployKey, Project, ProjectCommit, ProjectKey, ProjectPipelineSchedule, User
 from gitlab.v4.objects.variables import ProjectVariable
 
-from ..app_args import get_app_args
-from ..gitlab import init_gitlab_client
-from ..model import FetcherDef, FetcherDefNotFound, FetcherMetadata, FileDef, PipelineV5Config, ScheduleDef
-from ..ssh import generate_ssh_key_pair
-from ..utils import find_index
+from dbnomics_fetcher_ops.app_args import get_app_args
+from dbnomics_fetcher_ops.cli_utils import check_provider_slug_is_lowercase, get_fetcher_def_not_found_error_message
+from dbnomics_fetcher_ops.gitlab_utils import init_gitlab_client
+from dbnomics_fetcher_ops.model.errors import FetcherDefNotFound
+from dbnomics_fetcher_ops.model.fetcher_metadata.base import FetcherDef, ScheduleDef
+from dbnomics_fetcher_ops.model.fetcher_metadata.gitlab import GitLabFetcherMetadata
+from dbnomics_fetcher_ops.model.pipelines_config import FileDef, PipelineV5Config
+from dbnomics_fetcher_ops.ssh import generate_ssh_key_pair
+from dbnomics_fetcher_ops.utils import find_index
 
 logger = daiquiri.getLogger(__name__)
 
@@ -59,7 +61,7 @@ def configure_fetcher(
     fetcher_def: FetcherDef,
     *,
     debug_gitlab: bool,
-    fetcher_metadata: FetcherMetadata,
+    fetcher_metadata: GitLabFetcherMetadata,
     gitlab_private_token: str,
     pipeline_v5_config: PipelineV5Config,
 ):
@@ -122,7 +124,7 @@ class Context:
     provider_slug: str
 
 
-def init_fetcher_project(gl: gitlab.Gitlab, fetcher_metadata: FetcherMetadata, ctx: Context) -> Project:
+def init_fetcher_project(gl: gitlab.Gitlab, fetcher_metadata: GitLabFetcherMetadata, ctx: Context) -> Project:
     """Load or fork or create fetcher project."""
     project_ref = fetcher_metadata.gitlab.fetcher
     fetcher_group_name, fetcher_project_name = project_ref.expand_group_and_name(ctx.provider_slug)
@@ -151,7 +153,9 @@ def init_fetcher_project(gl: gitlab.Gitlab, fetcher_metadata: FetcherMetadata, c
     return create_project(fetcher_group_name, fetcher_project_name, fetcher_description, ctx)
 
 
-def load_or_create_source_data_project(gl: gitlab.Gitlab, fetcher_metadata: FetcherMetadata, ctx: Context) -> Project:
+def load_or_create_source_data_project(
+    gl: gitlab.Gitlab, fetcher_metadata: GitLabFetcherMetadata, ctx: Context
+) -> Project:
     source_data_group_name, source_data_project_name = fetcher_metadata.gitlab.source_data.expand_group_and_name(
         ctx.provider_slug
     )
@@ -165,7 +169,9 @@ def load_or_create_source_data_project(gl: gitlab.Gitlab, fetcher_metadata: Fetc
     return create_project(source_data_group_name, source_data_project_name, source_data_description, ctx)
 
 
-def load_or_create_json_data_project(gl: gitlab.Gitlab, fetcher_metadata: FetcherMetadata, ctx: Context) -> Project:
+def load_or_create_json_data_project(
+    gl: gitlab.Gitlab, fetcher_metadata: GitLabFetcherMetadata, ctx: Context
+) -> Project:
     json_data_group_name, json_data_project_name = fetcher_metadata.gitlab.json_data.expand_group_and_name(
         ctx.provider_slug
     )
@@ -276,7 +282,7 @@ def setup_pipeline_variables(
     source_data_project: Project,
     json_data_project: Project,
     fetcher_def: FetcherDef,
-    fetcher_metadata: FetcherMetadata,
+    fetcher_metadata: GitLabFetcherMetadata,
 ):
     """Setup pipeline variables in CI settings.
 
