@@ -6,7 +6,8 @@ import requests
 import validators
 import yaml
 
-from .model import FetcherMetadata, PipelinesConfig
+from dbnomics_fetcher_ops.model.fetcher_metadata.gitlab import GitLabFetcherMetadata
+from dbnomics_fetcher_ops.model.pipelines_config import PipelinesConfig
 
 __all__ = ["load_fetchers_yml", "load_pipelines_yml"]
 
@@ -24,10 +25,10 @@ def load_bytes(source: str) -> bytes:
     return Path(source).read_bytes()
 
 
-def load_fetchers_yml(fetchers_yml_ref: str) -> FetcherMetadata:
+def load_fetchers_yml(fetchers_yml_ref: str) -> GitLabFetcherMetadata:
     logger.debug("Loading fetcher metadata from %s...", fetchers_yml_ref)
     fetchers_yml_data = load_yml_file(fetchers_yml_ref)
-    return FetcherMetadata.parse_obj(fetchers_yml_data)
+    return GitLabFetcherMetadata.parse_obj(fetchers_yml_data)
 
 
 def load_pipelines_yml(pipelines_yml_ref: str) -> PipelinesConfig:
